@@ -1,3 +1,4 @@
+from ..inbox_filter.relevants_filter import RelevantsFilter
 from .rest.operation_mode import OperationMode
 from .detector import Detector
 from .rest import detect, upload, operation_mode
@@ -35,9 +36,10 @@ class DetectorNode(Node):
         self.project = os.environ.get('LOOP_PROJECT', None) or os.environ.get('PROJECT', None)
         assert self.organization, 'Detector node needs an organization'
         assert self.project, 'Detector node needs an project'
-        self.operation_mode = OperationMode.Startup
-        self.connected_clients = []
-        self.outbox = Outbox()
+        self.operation_mode: OperationMode = OperationMode.Startup
+        self.connected_clients: List[str] = []
+        self.outbox: Outbox = Outbox()
+        self.relevants_filter: RelevantsFilter = RelevantsFilter(self.outbox)
         self.target_model = None
         self.include_router(detect.router, tags=["detect"])
         self.include_router(upload.router, prefix="")
@@ -67,7 +69,7 @@ class DetectorNode(Node):
         async def _detect(sid, data) -> None:
             try:
                 np_image = np.frombuffer(data['image'], np.uint8)
-                return await self.get_detections(np_image, data.get('mac', None), data.get('tags', []), data.get('active_learning', True))
+                return await self.get_detections(np_image, data.get('mac', None), data.get('tags', []))
             except Exception as e:
                 logging.exception('could not detect via socketio')
                 with open('/tmp/bad_img_from_socket_io.jpg', 'wb') as f:
@@ -102,7 +104,6 @@ class DetectorNode(Node):
         if self.operation_mode == OperationMode.Startup:
             return
         try:
-            ic()
             logging.info(f'periodically checking operation mode. Current mode is {self.operation_mode}')
             update_to_model_id = await self.send_status()
             if self.detector.current_model:
@@ -189,15 +190,15 @@ class DetectorNode(Node):
         else:
             subprocess.call(['touch', '/app/main.py'])
 
-    async def get_detections(self, raw_image, mac: str, tags: str, active_learning=True):
+    async def get_detections(self, raw_image, mac: str, tags: str):
         loop = asyncio.get_event_loop()
-        # image = await loop.run_in_executor(None, lambda: cv2.imdecode(np_image, cv2.IMREAD_COLOR))
         detections = await loop.run_in_executor(None, self.detector.evaluate, raw_image)
         info = "\n    ".join([str(d) for d in detections.box_detections])
         logging.info(f'detected:\n    {info}')
-        # if active_learning:
-        #     thread = Thread(target=learn, args=(detections, mac, tags, image))
-        #     thread.start()
+
+        thread = Thread(target=self.relevants_filter.learn, args=(detections, mac, tags, raw_image))
+        thread.start()
+
         return jsonable_encoder(detections)
 
     async def upload_images(self, images: List[bytes]):
